@@ -1,6 +1,5 @@
 __all__ = ["fit_ols", "ft_ols"]
 
-## Fitting via statsmodels package
 from numpy import zeros
 from pandas import DataFrame
 
@@ -11,7 +10,7 @@ except ModuleNotFoundError:
     raise ModuleNotFoundError("module statsmodels not found")
 
 import grama as gr
-from grama import pipe
+from grama import add_pipe, pipe
 from toolz import curry
 
 ## Fit model via OLS
@@ -66,6 +65,4 @@ def fit_ols(df, formulae=[""], domain=None, density=None):
     )
 
 
-@pipe
-def ft_ols(*args, **kwargs):
-    return fit_ols(*args, **kwargs)
+ft_ols = add_pipe(fit_ols)
